@@ -190,7 +190,7 @@ class Datalake:
             raise Exception(f'ids can not be None when file_category is IDS')
         ids_obj = VersionedRef(composite=ids)
         pattern = '(.*?)/(.*?)/(?:.*?)/(.*)'
-        match = re.match(pattern, raw_file_key)
+        match = re.match(pattern, raw_file_key, flags=re.DOTALL)
         if not match:
             raise Exception(f'Raw file key {raw_file_key} does not match "{pattern}"')
 
@@ -307,6 +307,8 @@ class Datalake:
         if len(custom_meta_str) + len(custom_tags_str) >= 1024 * 1.5:
             raise Exception('Metadata and tags length larger than 1.5KB')
 
+        file_id = str(uuid4())
+
         params = {
             'Bucket': bucket,
             'CopySource': f'/{bucket}/{file_key}',
@@ -316,6 +318,7 @@ class Datalake:
             'ContentType': head['ContentType'],
             'Metadata': {
                 **current_meta,
+                FIELDS['FILE_ID']: file_id,
                 FIELDS['CUSTOM_METADATA']: custom_meta_str,
                 FIELDS['CUSTOM_TAGS']: custom_tags_str
             },
@@ -331,7 +334,7 @@ class Datalake:
             'type': 's3file',
             'bucket': bucket,
             'fileKey': file_key,
-            'fileId': current_meta[FIELDS['FILE_ID']],
+            'fileId': file_id,
             # fakeS3 does not return VersionId, so use '' to avoid an exception
             'version': response.get('VersionId', '')
         }
